@@ -7,10 +7,9 @@ from helloasso_python.api.commandes_api import CommandesApi
 from helloasso_python.api.formulaires_api import FormulairesApi
 from helloasso_python.api.liste_de_valeurs_api import ListeDeValeursApi
 from helloasso_python.api.organisation_api import OrganisationApi
-from helloasso_python.api.organization_legal_informations_api import OrganizationLegalInformationsApi
 from helloasso_python.api.paiements_api import PaiementsApi
 from helloasso_python.api.partenaires_api import PartenairesApi
+from helloasso_python.api.reus_fiscaux_api import ReusFiscauxApi
 from helloasso_python.api.tags_api import TagsApi
-from helloasso_python.api.tax_receipt_api import TaxReceiptApi
 from helloasso_python.api.utilisateurs_api import UtilisateursApi
 
